@@ -8,7 +8,6 @@ from revauth.serializers import ProfileJWTSerializer
 from django.db.utils import IntegrityError
 import requests
 from django.conf import settings
-from r
 
 
 class BaseHandler:
@@ -17,12 +16,13 @@ class BaseHandler:
     identity_type = api_settings.DEFAULT_IDENTITY
     issuer = api_settings.DEFAULT_VALIDATION_ISSUER
     DEBUG = settings.DEBUG
+    auth_version = api_settings.DEFAULT_AUTH_VERSION
 
     @property
     def auth_host(self):
         if self.DEBUG:
-            return f'https://auth-stg.revtel-api.com/v2/validation/request?issuer={self.issuer}&client_id={settings.CLIENT_ID}'
-        return f'https://auth.revtel-api.com/v2/validation/request?issuer={self.issuer}&client_id={settings.CLIENT_ID}'
+            return f'https://auth-stg.revtel-api.com/{self.auth_version}/validation/request?issuer={self.issuer}&client_id={settings.CLIENT_ID}'
+        return f'https://auth.revtel-api.com/{self.auth_version}/validation/request?issuer={self.issuer}&client_id={settings.CLIENT_ID}'
 
     def send_validation(self, identity):
         resp = requests.post(self.auth_host, json={'identity': identity})
