@@ -31,7 +31,7 @@ class BaseProvider:
         raise NotImplementedError('map profile data')
 
     def process_login(self, name, social_id, email='', phone='', **kwargs):
-        profile = self.profile_class.objects.filter(provider=self.provider, social_id=social_id)
+        profile = self.profile_class.objects.filter(provider=self.provider, social_id=social_id).last()
         if not profile:
             user = User.objects.create_user(username=uuid4().__str__())
             try:
